==> odoo_addon_energy_communities-16.0.0.2.2.tar.gz: odoo_addon_energy_communities-16.0.0.2.2/odoo/addons/energy_communities/__manifest__.py <==
{
    "name": "Energy Community",
    "version": "16.0.0.2.2",
    "depends": [
        "account",
        "account_banking_mandate",
        "account_lock_date_update",
        "account_multicompany_easy_creation",
        "account_payment_order",
        "account_reconcile_oca",
        "auth_api_key",
        "auth_oidc",
        "auth_signup",
        "base",
        "base_rest",
        "base_technical_features",
        "base_user_role",
        "base_user_role_company",
        "calendar",
        "community_maps",
        "contacts",
        "event",
        "l10n_es_aeat",
        "l10n_es_aeat_sii_oca",
        "mail",
        "mail_multicompany",
        "metadata",
        "partner_firstname",
        "partner_multi_company",
        "purchase",
        "queue_job",
        "sale_management",
        "sales_team",
        "website_event",
    ],
    "author": "Coopdevs Treball SCCL & Som Energia SCCL",
    "website": "https://coopdevs.org",
    "category": "Cooperative management",
    "description": """
    Energy Communities customizations.
    """,
    "license": "AGPL-3",
    "demo": [
        "demo/res_lang_demo.xml",
        "demo/res_company_demo.xml",
        "demo/res_partner_demo.xml",
        "demo/res_user_demo.xml",
    ],
    "data": [
        "security/res_users_role_data.xml",
        "security/ir_rule_data.xml",
        "security/ir.model.access.csv",
        "data/product_data.xml",
        "data/auth_oauth_provider_data.xml",
        "data/ir_cron.xml",
        "data/mail_templates_email_layouts.xml",
        "data/utm_data.xml",
        "data/energy_action.xml",
        "views/mail_template_views.xml",
        "views/account_move_views.xml",
        "views/landing_page_view.xml",
        "views/res_company_views.xml",
        "views/res_config_settings.xml",
        "views/res_partner_bank_views.xml",
        "views/res_partner_views.xml",
        "views/cm_place.xml",
        "views/energy_action_views.xml",
        "views/utm_views.xml",
        "views/auth_oauth_views.xml",
        "views/view_users_form.xml",
        "views/product_views.xml",
        "views/res_users_view.xml",
        "views/res_users_role_view.xml",
        "views/menus.xml",
        "views/website_form_submit_confirmation.xml",
        "views/website_formfields_template.xml",
        "views/account_banking_mandate_views.xml",
        "data/community_maps_data.xml",
        "wizards/multicompany_easy_creation.xml",
        "wizards/create_users_wizard.xml",
        "wizards/change_coordinator_wizard.xml",
    ],
    "installable": True,
    "application": True,
    "auto_install": False,
    "post_init_hook": "post_init_hook",
}

==> odoo_addon_energy_communities-16.0.0.3.1.tar.gz: odoo_addon_energy_communities-16.0.0.3.1/odoo/addons/energy_communities/__manifest__.py <==
{
    "name": "Energy Community",
    "version": "16.0.0.3.1",
    "depends": [
        "account",
        "account_banking_mandate",
        "account_lock_date_update",
        "account_multicompany_easy_creation",
        "account_payment_order",
        "account_reconcile_oca",
        "auth_api_key",
        "auth_oidc",
        "auth_signup",
        "base",
        "base_rest",
        "base_technical_features",
        "base_user_role",
        "base_user_role_company",
        "calendar",
        "community_maps",
        "community_maps_key_submissions",
        "contacts",
        "event",
        "l10n_es_aeat",
        "l10n_es_aeat_sii_oca",
        "mail",
        "mail_multicompany",
        "mail_template_multi_company",
        "metadata",
        "partner_firstname",
        "partner_multi_company",
        "purchase",
        "queue_job",
        "sale_management",
        "sales_team",
        "website_event",
    ],
    "author": "Coopdevs Treball SCCL & Som Energia SCCL",
    "website": "https://git.coopdevs.org/coopdevs/comunitats-energetiques/odoo-ce",
    "category": "Cooperative management",
    "description": """
    Energy Communities customizations.
    """,
    "license": "AGPL-3",
    "demo": [
        "demo/res_lang_demo.xml",
        "demo/res_company_demo.xml",
        "demo/res_user_demo.xml",
    ],
    "data": [
        "security/res_groups_roles_data.xml",
        "security/ir.model.access.csv",
        "security/ir_rule_data_account.xml",
        "security/ir_rule_data_landing_page.xml",
        "security/ir_rule_data_mail.xml",
        "security/ir_rule_data_partner.xml",
        "data/product_data.xml",
        "data/auth_oauth_provider_data.xml",
        "data/ir_cron.xml",
        "data/mail_templates_email_layouts.xml",
        "data/utm_data.xml",
        "data/energy_action.xml",
        "views/mail_template_views.xml",
        "views/account_move_views.xml",
        "views/landing_page_view.xml",
        "views/res_company_views.xml",
        "views/res_config_settings.xml",
        "views/res_partner_bank_views.xml",
        "views/res_partner_views.xml",
        "views/cm_place.xml",
        "views/energy_action_views.xml",
        "views/utm_views.xml",
        "views/auth_oauth_views.xml",
        "views/view_users_form.xml",
        "views/product_views.xml",
        "views/res_users_view.xml",
        "views/res_users_role_view.xml",
        "views/menus.xml",
        "views/website_form_submit_confirmation.xml",
        "views/website_formfields_template.xml",
        "views/account_banking_mandate_views.xml",
        "data/community_maps_data.xml",
        "wizards/multicompany_easy_creation.xml",
        "wizards/create_users_wizard.xml",
        "wizards/change_coordinator_wizard.xml",
    ],
    "installable": True,
    "application": True,
    "auto_install": False,
    "post_init_hook": "post_init_hook",
}
